#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SELSUB_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SELSUB_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/scalar/selsub.hpp>

#endif
